PeckishHandTutorialModel class
Constructors
-
PeckishHandTutorialModel({required Widget child, required List<
ShowcaseItem> items, ShowcaseController? controller, double? handSize = 50, Color? handColor = Colors.white, Duration animationDuration = const Duration(seconds: 3), String? handAssetPath, ToolTip toolTip = const ToolTip(), Duration? initialDelay, Function? onAnimationComplete, Widget tooltipBuilder(String tooltip)?, Function? triggerWhen, bool? haveRippleEffect = false})
Properties
- animationDuration → Duration
-
final
- child → Widget
-
final
- controller → ShowcaseController?
-
final
- handAssetPath → String?
-
final
- handColor → Color?
-
final
- handSize → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- haveRippleEffect → bool?
-
final
- initialDelay → Duration?
-
final
-
items
→ List<
ShowcaseItem> -
final
- onAnimationComplete → Function?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toolTip → ToolTip
-
final
- tooltipBuilder → Widget Function(String tooltip)?
-
final
- triggerWhen → Function?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited